@@ -558,6 +558,28 @@ TEST(StringUtils, Split)  // NOLINT
   EXPECT_EQ(v({"", "home", "cras", "file", "path"}), split("/home/cras/file/path", "/"));
 }
 
+TEST(StringUtils, ToUpper)  // NOLINT
+{
+  EXPECT_EQ("TEST", cras::toUpper("test"));
+  EXPECT_EQ("TEST", cras::toUpper("Test"));
+  EXPECT_EQ("TEST", cras::toUpper("TEST"));
+  EXPECT_EQ("TEST", cras::toUpper("TeST"));
+  EXPECT_EQ("", cras::toUpper(""));
+  EXPECT_EQ("1234567890", cras::toUpper("1234567890"));
+//  EXPECT_EQ("ĚŠČŘŽÝÁÍÉĎŤŇÚŮ", cras::toUpper("ěščřžýáíéďťňúů"));  // not yet working
+}
+
+TEST(StringUtils, ToLower)  // NOLINT
+{
+  EXPECT_EQ("test", cras::toLower("test"));
+  EXPECT_EQ("test", cras::toLower("Test"));
+  EXPECT_EQ("test", cras::toLower("TEST"));
+  EXPECT_EQ("test", cras::toLower("TeST"));
+  EXPECT_EQ("", cras::toUpper(""));
+  EXPECT_EQ("1234567890", cras::toUpper("1234567890"));
+//  EXPECT_EQ("ěščřžýáíéďťňúů", cras::toLower("ĚŠČŘŽÝÁÍÉĎŤŇÚŮ"));  // not yet working
+}
+
 void test_va_format(const std::string& res, const char* format, ...)
 {
   va_list(args);
@@ -1146,8 +1168,8 @@ TEST(StringUtils, ParseFloat)  // NOLINT
   EXPECT_EQ(-3.141592f, cras::parseFloat("-3.141592"));
   EXPECT_EQ(3.402823466e+38f, cras::parseFloat("3.402823466e+38"));
   EXPECT_EQ(-3.402823466e+38f, cras::parseFloat("-3.402823466e+38"));
-  EXPECT_EQ(std::numeric_limits<float>::infinity(), cras::parseFloat("3.5e+38"));
-  EXPECT_EQ(-std::numeric_limits<float>::infinity(), cras::parseFloat("-3.5e+38"));
+  EXPECT_THROW(cras::parseFloat("3.5e+38"), std::invalid_argument);
+  EXPECT_THROW(cras::parseFloat("-3.5e+38"), std::invalid_argument);
   EXPECT_THROW(cras::parseFloat(" 1.0  "), std::invalid_argument);
   EXPECT_THROW(cras::parseFloat("1 .0"), std::invalid_argument);
   EXPECT_THROW(cras::parseFloat("1. 0"), std::invalid_argument);
@@ -1180,8 +1202,8 @@ TEST(StringUtils, ParseDouble)  // NOLINT
   EXPECT_EQ(-3.141592, cras::parseDouble("-3.141592"));
   EXPECT_EQ(1.79769e+308, cras::parseDouble("1.79769e+308"));
   EXPECT_EQ(-1.79769e+308, cras::parseDouble("-1.79769e+308"));
-  EXPECT_EQ(std::numeric_limits<double>::infinity(), cras::parseDouble("1.8e+308"));
-  EXPECT_EQ(-std::numeric_limits<double>::infinity(), cras::parseDouble("-1.8e+308"));
+  EXPECT_THROW(cras::parseDouble("1.8e+308"), std::invalid_argument);
+  EXPECT_THROW(cras::parseDouble("-1.8e+308"), std::invalid_argument);
   EXPECT_THROW(cras::parseDouble(" 1.0  "), std::invalid_argument);
   EXPECT_THROW(cras::parseDouble("1 .0"), std::invalid_argument);
   EXPECT_THROW(cras::parseDouble("1. 0"), std::invalid_argument);
